# Streamlit XUI

An extended set of UI components for use in streamlit

- st_xui_sidemenu
- st_xui_placeholder

## Installation

```
pip install streamlit-xui
```

## Usage

Refer to the following files for example usage
- [placeholder](https://github.com/ais-one/favv/blob/master/streamlit/component-template/streamlit-xui/placeholder/__init__.py)
- [sidemenu](https://github.com/ais-one/favv/blob/master/streamlit/component-template/streamlit-xui/sidemenu/__init__.py)

